@@ -1,5 +1,5 @@
+from ids_validator.checks.abstract_checker import CheckResults, AbstractChecker
 from ids_validator.ids_node import Node
-from ids_validator.checks import AbstractChecker
 from ids_validator.utils import Log
 
 
@@ -11,7 +11,7 @@ class RequiredPropertiesChecker(AbstractChecker):
     logs a failure if the check fails.
     """
 
-    def run(self, node: Node, context: dict = None):
+    def run(self, node: Node, context: dict = None) -> CheckResults:
         logs = []
         if node.has_required_list:
             missing_properties = node.missing_properties
