@@ -1,10 +1,8 @@
-import os
 from pathlib import Path
-from pydash import get
-from ids_validator.ids_node import Node
-from ids_validator.checks import AbstractChecker
-from ids_validator.utils import Log, read_schema
 
+from ids_validator.checks.abstract_checker import AbstractChecker, CheckResults
+from ids_validator.ids_node import Node
+from ids_validator.utils import Log, read_schema
 
 TEMPLATES_DIR = (Path(__file__) / "../../../templates").resolve()
 RELATED_FILES_TEMPLATE = TEMPLATES_DIR / "related_files.json"
@@ -12,7 +10,11 @@ RELATED_FILES = "root.properties.related_files"
 
 
 class V1RelatedFilesChecker(AbstractChecker):
-    def run(self, node: Node, context: dict):
+    """
+    Check that the related files schema matches the template from the schema conventions
+    """
+
+    def run(self, node: Node, context: dict = None) -> CheckResults:
         logs = []
         if node.path == RELATED_FILES:
             if not RELATED_FILES_TEMPLATE.exists():
@@ -28,7 +30,8 @@ class V1RelatedFilesChecker(AbstractChecker):
             if related_files_template["related_files"] != node.data:
                 logs += [
                     (
-                        "'related_files' isn't an exact match of the template. Please refer to confluence docs.",
+                        "'related_files' isn't an exact match of the template. Please "
+                        "refer to the related files schema template documentation",
                         Log.CRITICAL.value,
                     )
                 ]
