@@ -1,9 +1,7 @@
-from os import stat
+from ids_validator.checks.abstract_checker import CheckResults, AbstractChecker
 from ids_validator.ids_node import Node
-from ids_validator.checks import AbstractChecker
 from ids_validator.utils import Log
 
-
 ignored_paths = [
     "root.properties.related_files.items.properties.pointer.properties.fileId",
     "root.properties.related_files.items.properties.pointer.properties.fileKey",
@@ -13,7 +11,7 @@ DEFINITIONS_PATH = "root.definitions"
 
 
 class V1SnakeCaseChecker(AbstractChecker):
-    def run(self, node: Node, context: dict = None):
+    def run(self, node: Node, context: dict = None) -> CheckResults:
         logs = []
 
         if node.path in ignored_paths or node.path.startswith(DEFINITIONS_PATH):
